# MutaGene
Python package for mutational analysis

Project website: https://www.ncbi.nlm.nih.gov/research/mutagene/

* Rank mutations and identify potential driver mutations by comparing exepected mutability to observed recurrence in cancer patients
